pub enum UlpCoreWakeupSource {
HpCpu,
Timer(UlpCoreTimerCycles),
}Expand description
Enum representing the possible wakeup sources for the ULP core.
Variants
HpCpu
Wakeup source from the HP (High Performance) CPU.
Timer(UlpCoreTimerCycles)
Wakeup after the ULP Timer has elapsed. The actual period between wake-ups is affected by the runtime duration of the ULP program.