UlpCoreTimerCycles

Struct UlpCoreTimerCycles 

pub struct UlpCoreTimerCycles { /* private fields */ }
ULP Timer cycles are clocked at a rate of approximately 17.5MHz / 32768 = ~534 Hz.

Implementations

Source

impl UlpCoreTimerCycles

pub const fn new(cycles: u32) -> Self

Creates a new Ulp Timer cycle count configuration.

Panics

Panics if the cycles value is outside of the value range (0 ..= 0xFFFFFF).